# {{PACKAGE_TITLE}}

> Please read `docs/swagger.json` or `docs/swagger.yaml` for more information.

## Usage

### Build

```shell
make build  # Current platform
make linux-armv7 # Specify platform
make builds # Most used
make all-arch # All platforms golang supported
```

### Commands

```shell
$ ./{{APP_NAME}} -h

```

## Makefile Default

> Please read `Makefile` for more information.

### Start

```shell
make start
```

### Stop

```shell
make stop
```

### Restart

```shell
make restart
```
